@@ -150,7 +150,7 @@ class ProtocolHandler:
 		#check len
 		l = len(message)
 		if l>=(MAX_LINE_LENGTH-16):
-			self.serror("message is too long: %d (maximum is %d)" % (visible_command(message), l, MAX_LINE_LENGTH), None, message)
+			self.serror("message is too long: %s (maximum is %s)" % (l, MAX_LINE_LENGTH), None, visible_command(message))
 		else:
 			self.send_method(message)
 		return	message
