@@ -404,15 +404,33 @@ class ServerSettings(ServerBase):
 
 
 	def detect_xpra_encodings(self):
+		try:
+			all_encodings = []
+			from xpra.codecs.loader import has_codec
+			for codec_name, encodings in {
+						"enc_vpx" 	: ["vpx"],
+						"enc_x264"	: ["x264"],
+					  	"enc_webp"  : ["webp"],
+						"PIL"	    : ["png", "png/L", "png/P", "jpeg"],
+						}.items():
+				if has_codec(codec_name):
+					all_encodings += encodings
+			logger.slog("=%s" % str(all_encodings))
+			return all_encodings
+		except:
+			pass
+		#older versions:
 		try:
 			from xpra.scripts.config import ENCODINGS			#@UnresolvedImport
 			return	ENCODINGS
 		except:
-			try:
-				from xpra.scripts.main import ENCODINGS			#@UnresolvedImport @Reimport
-				return	ENCODINGS
-			except:
-				pass
+			pass
+		#even older:
+		try:
+			from xpra.scripts.main import ENCODINGS			#@UnresolvedImport @Reimport
+			return	ENCODINGS
+		except:
+			pass
 		return	[]
 
 	def test_supports_fileopen(self):
