@@ -218,6 +218,10 @@ class	XpraServerUtil(ServerUtilBase):
 			and session.status not in [Session.STATUS_CONNECTED, Session.STATUS_CONNECTING, Session.STATUS_IDLE]:
 			return	Session.STATUS_CONNECTING
 		elif l.startswith("Password matches!"):
+			#versions before 0.11:
+			return	Session.STATUS_CONNECTED
+		elif l.find("client version ")>=0:
+			#version >= 0.11
 			return	Session.STATUS_CONNECTED
 		elif l.startswith("xpra client disconnected."):
 			return	Session.STATUS_AVAILABLE
